@@ -31,6 +31,7 @@
 #ifdef GDK_WINDOWING_X11
 #include <gdk/gdkx.h>
 #endif
+#include <libhandy-1/handy.h>
 #include <stdlib.h>
 
 #include "yelp-bookmarks.h"
@@ -270,6 +271,10 @@ yelp_application_startup (GApplication *application)
     /* chain up */
     G_APPLICATION_CLASS (yelp_application_parent_class)->startup (application);
 
+    hdy_init ();
+    hdy_style_manager_set_color_scheme (hdy_style_manager_get_default (),
+                                        HDY_COLOR_SCHEME_PREFER_LIGHT);
+
     settings = yelp_settings_get_default ();
     if (editor_mode)
         yelp_settings_set_editor_mode (settings, TRUE);
